@@ -1,7 +1,7 @@
 #' Plot Residuals from MLDFM
 #'
 #' @import ggplot2
-#' @importFrom stats cov
+#' @importFrom stats cor
 #'
 #' @keywords internal
 plot_residuals.mldfm <- function(x, var_names = NULL, ...) {
@@ -15,21 +15,21 @@ plot_residuals.mldfm <- function(x, var_names = NULL, ...) {
     var_names
   }
   
-  # Compute covariance matrix
-  cov_matrix <- cov(Residuals)
-  rownames(cov_matrix) <- country_names
-  colnames(cov_matrix) <- country_names
+  # Compute Correlation matrix
+  corr_matrix <- cor(Residuals)
+  rownames(corr_matrix) <- country_names
+  colnames(corr_matrix) <- country_names
   
   # Convert to long format
-  cov_df <- as.data.frame(as.table(cov_matrix))
-  colnames(cov_df) <- c("Country1", "Country2", "Covariance")
+  corr_df <- as.data.frame(as.table(corr_matrix))
+  colnames(corr_df) <- c("Country1", "Country2", "Correlation")
   
-  Country1 <- Country2 <- Covariance <- NULL # Setting the variables to NULL first
+  Country1 <- Country2 <- Correlation <- NULL # Setting the variables to NULL first
   
   # Plot
-  g <- ggplot(cov_df, aes(x = Country1, y = Country2, fill = Covariance)) +
+  g <- ggplot(corr_df, aes(x = Country1, y = Country2, fill = Correlation)) +
     geom_tile(color = "white", linewidth = 0.1) +
-    scale_fill_viridis_c(option = "D", name = "Covariance") +
+    scale_fill_distiller(palette = "RdYlBu", limits = c(-1, 1), name = "Correlation") +
     labs(title = "Residuals",
          x = NULL, y = NULL) +
     theme_minimal(base_size = 11) +
