@@ -1,30 +1,19 @@
 #' Quantile Regression with Stressed Scenario Projection
 #'
 #' Estimates quantile regressions of a dependent variable on dynamic factors.
-#' If a \code{scenario} is provided (e.g., a list of ellipsoids from \code{create_scenario()}),
-#' the function computes the minimum (or maximum) projected quantile values under stress.
 #'
 #' @import quantreg
 #' @importFrom stats as.formula
 #' 
 #' @keywords internal
 #' 
-q_reg <- function(dep_variable, factors, h=1,  QTAU=0.05,  scenario = NULL, min = TRUE) {
+q_reg <- function(dep_variable, factors, Stressed_Factors = NULL,  h=1,  QTAU=0.05) {
   
   
   t <- nrow(factors)
   r <- ncol(factors)
 
   
-  index_list <- c(
-    1308, 2172, 2172, 2748, 2748, 2748, 2026, 1310, 2172, 1884,
-    1844, 1844, 2132, 732, 1844, 1844, 1818, 1811, 734, 1844,
-    1844, 2132, 1844, 1884, 1884, 1884, 1884, 1884, 1884, 1884,
-    1884, 1884, 1738, 1884, 2132, 1884, 1844, 1844, 1844, 782,
-    1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
-    1844, 1844, 1844, 1844, 1836, 1844, 1844, 1836, 1844
-  )
-  
   # Prepare regression data
   Y <- dep_variable
   LagY<-shift(Y,h)
@@ -55,52 +44,22 @@ q_reg <- function(dep_variable, factors, h=1,  QTAU=0.05,  scenario = NULL, min
   
  
   # Predict quantile with estimated factors
-  Pred_q <- as.numeric(coefficients[1])
-  Pred_q <- Pred_q + as.numeric(coefficients[2]) * Y[] 
-  for (i in 1:r) {
-    Pred_q <- Pred_q + as.numeric(coefficients[i+2]) * factors[, i]
-  }
+  Pred_q <- coefficients[1] + coefficients[2] * Y + as.numeric(factors %*% coefficients[3:(2 + r)])
     
   
-  # Return here is scenario quantiles are not needed
-  if (is.null(scenario)) {
+  # Return here if strssed quantiles are not needed
+  if (is.null(Stressed_Factors)) {
     return(list(Pred_q = Pred_q, Coeff = coefficients, Pvalues = pvalues, StdError = std_errors))
   }
   
   
-  # qreg scenario
-  Scenario_Pred_q <- vector(mode = "numeric", length = t)
+  # Predict with stressed factors (if provided)
+  Stressed_Pred_q <- coefficients[1] + coefficients[2] * Y + as.numeric(Stressed_Factors %*% coefficients[3:(2 + r)])
   
-  for (tt in 1:t){
-    ellips <- scenario[[tt]]
-    points <- nrow(ellips)
-    pred <- vector(mode = "numeric", length = points)
-    
-    for(p in 1:points){
-      pred[p] <- as.numeric(coefficients[1])
-      pred[p] <- pred[p] + as.numeric(coefficients[2]) * Y[tt] 
-      
-      for (j in 1:r) {
-        pred[p] <- pred[p] + as.numeric(coefficients[j+2]) * ellips[p,j]
-      }
-    }
-    
-    
-    if(min == TRUE){
-      value <- min(pred)
-      #index <- which.min(pred)
-    }else{
-      value <- max(pred)
-    }
-    
-    Scenario_Pred_q[tt] <- value
-  }
-    
- 
   # return
   return(list(Pred_q = Pred_q, Coeff = coefficients, Pvalues = pvalues, 
-              StdError = std_errors, Scenario_Pred_q = Scenario_Pred_q))
-
+              StdError = std_errors, Stressed_Pred_q = Stressed_Pred_q))
+  
 }
 
 
